/*
 * Project name:
      Buggy Clicker2
 * Copyright:
      (c) mikroElektronika, 2015.
 * Description:
    - This project demonstrates wireless Buggy control, using
      clicker2 for STM32, BLE-P click board and Android smart phone.
 * Test configuration:
     MCU:             P32MX795F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61156F.pdf
     Dev.Board:       EasyPIC Fusion v7
                      http://www.mikroe.com/easypic-fusion/
     Oscillator:      XT-PLL, 80.000MHz
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/mikroc/pic32/
     Link:            http://www.mikroe.com/buggy/

 * NOTES:
    - Application for Android smart phone can be found on following link:
      https://play.google.com/store/apps/details?id=com.mikroe.buggy&hl=en
*/

#include "Blep.h"
#include "aci_cmds.h"
#include "aci_evts.h"
#include "Buggy.h"

sbit LED_CONN at LATE3_bit;
sbit LED_DATA at LATA10_bit;
sbit LED_CONN_Direction at TRISE3_bit;
sbit LED_DATA_Direction at TRISA10_bit;

extern char writeBuff[32];
extern short readBuff[32];
char CONN_STATE = 0;
char BOND_STATE = 0;
char BREAK_FLAG;
char NEW_EVT, EVT_STATUS, EVT_OPCODE;

extern sfr sbit Blep_RST;
extern sfr sbit Blep_RDY;
extern sfr sbit Blep_REQ;
extern sfr sbit Blep_ACT;

void Init_MCU() {
   AD1PCFG = 0x8000;
   
   TRISE2_bit = 0;
   TRISE8_bit = 1;
   TRISG13_bit = 0;
   TRISB0_bit = 1;

   Blep_RST = 0;
   
   SPI2_Init_Advanced(_SPI_MASTER, _SPI_8_BIT, 1,_SPI_SS_DISABLE, _SPI_DATA_SAMPLE_MIDDLE, _SPI_CLK_IDLE_LOW, _SPI_IDLE_2_ACTIVE);

   Blep_RST = 1;
   Delay_ms(100);
   Blep_RST = 0;
   Delay_ms(100);
   Blep_RST = 1;
   Blep_REQ = 1;
}

void main() {
  LED_CONN_Direction = 0;
  LED_DATA_Direction = 0;
  Delay_ms(200);
  Init_MCU();
  Init_Buggy();
  Blep_Setup();
  Delay_ms(100);
  LED_DATA = 0;
  LED_CONN = 0;
  Start_Buggy();
  Blep_Bond(0xB4, 0x20);
  
  while(1){
          NEW_EVT = Blep_EventCode();                                           //Wait for new event
          //EVT_STATUS = Blep_EventStatus();                                    //Event Status
          //EVT_OPCODE = Blep_EventOpcode();                                    //Event Opcode
          switch(NEW_EVT) {

                case ACI_EVT_HW_ERROR:
                  //DebugInfoEvent returns hardware error debug information
                  //This event is sent from nRF8001 to the external application
                  //controller to provide debug information. In case of firmware
                  //failure this event follows the DeviceStartedEvent.
                  if (CONN_STATE) {
                    delay_ms(20);
                  }else{
                    BREAK_FLAG = 1;
                  }
                  break;
                case ACI_EVT_CMD_RSP:
                  //CommandResponseEvent confirms reception or execution of an ACI command.
                  if (EVT_STATUS > 0x03) { //error
                   BREAK_FLAG = 1;
                  }
                  break;
                case ACI_EVT_CONNECTED:
                  CONN_STATE = 1;
                  LED_CONN = CONN_STATE;
                  break;
                case ACI_EVT_DISCONNECTED:
                  Break_Buggy();
                  CONN_STATE = 0;
                  LED_CONN = CONN_STATE;
                  LED_DATA = 0;
                  BOND_STATE = 0,
                  Blep_Bond(0xB4, 0x20);
                  break;
                case ACI_EVT_DATA_RECEIVED:
                   LED_DATA = ~LED_DATA;
                   OnDataReceived();

          }
  }
}